import os
import sys
from pathlib import Path
import unittest

FILE = Path(__file__).resolve()
ROOT = FILE.parents[1]  # visionai/visionai directory
if str(ROOT) not in sys.path:
    sys.path.append(str(ROOT))  # add ROOT to PATH

from util.general import WorkingDirectory, invoke_cmd

class TestInvoke(unittest.TestCase):
    @WorkingDirectory(ROOT)
    def test_invoke_camera(self):
        output = invoke_cmd(f'python main.py camera')
        assert 'Error' in output
        assert 'Missing command' in output

    @WorkingDirectory(ROOT)
    def test_invoke_camera_help(self):
        output = invoke_cmd('python main.py camera --help')
        assert 'Usage' in output
        assert 'Commands' in output
        assert 'add' in output
        assert 'list' in output
        assert 'remove' in output

    @WorkingDirectory(ROOT)
    def test_invoke_camera_add_help(self):
        output = invoke_cmd('python main.py camera add --help')
        assert 'Usage' in output
        assert 'camera' in output
        assert 'add' in output
        assert '--name' in output
        assert '--uri' in output
        assert '--description' in output
        assert '--help' in output

    @WorkingDirectory(ROOT)
    def test_invoke_camera_add_remove(self):
        # cleanup (prior test failures)
        output = invoke_cmd('python main.py camera remove --name TEST-999')

        # add camera
        output = invoke_cmd('python main.py camera add --name TEST-999 --uri youtube.com --description "Test camera"')
        assert 'Success' in output

        # list camera
        output = invoke_cmd('python main.py camera list')
        assert "'name': 'TEST-999'" in output
        assert "'uri': 'youtube.com'" in output

        # remove camera
        output = invoke_cmd('python main.py camera remove --name TEST-999')
        assert 'Success' in output

        # list camera
        output = invoke_cmd('python main.py camera list')
        assert "'name': 'TEST-999'" not in output


if __name__ == '__main__':
    unittest.main()



import os
import sys
from pathlib import Path
import unittest

FILE = Path(__file__).resolve()
ROOT = FILE.parents[1]  # visionai/visionai directory
if str(ROOT) not in sys.path:
    sys.path.append(str(ROOT))  # add ROOT to PATH

from util.general import WorkingDirectory, invoke_cmd

class TestInvoke(unittest.TestCase):
    @WorkingDirectory(ROOT)
    def test_invoke_main(self):
        output = invoke_cmd(f'python main.py')
        assert 'Error' in output
        assert 'Missing command' in output

    @WorkingDirectory(ROOT)
    def test_invoke_main_help(self):
        output = invoke_cmd('python main.py --help')
        assert 'VisionAI Toolkit' in output
        assert 'docs.visionify.ai' in output

if __name__ == '__main__':
    unittest.main()



import os
import sys
import typer
import time
import json
from uuid import uuid4
from rich import print
from rich.progress import track
from pathlib import Path

FILE = Path(__file__).resolve()
ROOT = FILE.parents[1]  # visionai/visionai directory
if str(ROOT) not in sys.path:
    sys.path.append(str(ROOT))  # add ROOT to PATH

from config import CONFIG_FILE

camera_app = typer.Typer()

# Camera app
@camera_app.command('list')
def camera_list():
    '''
    List available cameras

    Print cameras available in the system and the scenarios / routines
    that are set up for them.
    '''
    if not os.path.exists(CONFIG_FILE):
        print('No cameras available in the system')

    else:
        with open(CONFIG_FILE, 'r') as f:
            config_data = json.load(f)
        print(config_data['cameras'])

@camera_app.command('add')
def camera_add(
    name: str = typer.Option(..., help='Camera Name', prompt=True),
    uri: str = typer.Option(..., help='URI for camera', prompt=True),
    description: str = typer.Option(..., help='Description', prompt=True)
    ):
    '''
    Add a named camera instance

    Add a camera as a named instance in the system. For adding
    a camera we support RTSP, HLS, HTTP(S) systems. To add a camera
    you need to provide a name for the camera, URI for the camera
    (including any username/password within the URI itself),
    description for camera (about its location, where its pointing,
    who is the vendor etc.).

    Before the camera is added - we need to test out if the
    camera instance is valid. We need to be able to read from
    the camera and calculate its FPS. Show this information
    on the screen.
    '''

    print(f'Adding camera : {name}, {uri}, {description}')
    if os.path.exists(CONFIG_FILE):
        with open(CONFIG_FILE, 'r') as f:
            config_data = json.load(f)

        # Check if name already present
        for camera in config_data['cameras']:
            if camera['name'] == name:
                print(f'Error: Camera {name} already present')
                return

        # TODO: Maybe validate URI string also later.
    else:
        config_data = {
            'version': '0.1',
            'cameras': []
            }

    # TODO: Validate the camera stream is good (check FPS)
    config_data['cameras'].append({
        'id': str(uuid4()),
        'name': name,
        'uri': uri,
        'events': 'all',
        'preprocess': [],
        'scenarios': []
    })

    with open(CONFIG_FILE, 'w') as f:
        json.dump(config_data, f, indent=2)

    print('Successfully added camera.')


@camera_app.command('remove')
def camera_remove(name: str=typer.Option('Camera name', prompt=True, confirmation_prompt=True)):
    '''
    Remove a camera from the system

    Specify a named camera that needs to be removed from
    the system. Once removed, all the scenarios and pre-process
    routines associated with the camera will be removed.
    '''

    print(f'Removing camera : {name}')
    if not os.path.exists(CONFIG_FILE):
        print('No cameras available in the system. Exiting.')
        return

    with open(CONFIG_FILE, 'r') as f:
        config_data = json.load(f)

    # Check if name already present
    found = False
    for camera in config_data['cameras']:
        if camera['name'] == name:
            found = True
            config_data['cameras'].remove(camera)
            break

    if found:
        # Write back to JSON if successfully removed.
        with open(CONFIG_FILE, 'w') as f:
            json.dump(config_data, f, indent=4)

        print(f'Successfully removed camera: {name}')
    else:
        print(f'Unable to find camera {name} to remove')


@camera_app.command('preview')
def camera_preview(
    name:str = typer.Option(..., help='camera name to preview')
    ):
    '''
    Preview the camera system

    View the camera feed, review FPS etc available for camera.
    '''
    print(f"TODO: Implement camera preview functionality.")

@camera_app.callback()
def callback():
    '''
    Manage cameras

    An organization can have multiple cameras that are installed
    at different places. They may be from different vendors and/or
    maybe using different security surveillance software. Most
    cameras however do support RTSP, RTMP or HLS streams as an
    output. Please refer to your camera vendor documentation to
    find this out. This module will help you onboard those cameras
    on visionai systems by using a simple named instance for each
    camera.
    '''

if __name__ == '__main__':
    # camera_app()

    camera_remove('TEST-999')


import os
import sys
from pathlib import Path
import unittest

FILE = Path(__file__).resolve()
ROOT = FILE.parents[1]  # visionai/visionai directory
if str(ROOT) not in sys.path:
    sys.path.append(str(ROOT))  # add ROOT to PATH

from util.general import WorkingDirectory, invoke_cmd

class TestInvoke(unittest.TestCase):
    @WorkingDirectory(ROOT)
    def test_invoke_scenario(self):
        output = invoke_cmd(f'python main.py scenario')
        assert 'Error' in output
        assert 'Missing command' in output

    @WorkingDirectory(ROOT)
    def test_invoke_scenario_help(self):
        output = invoke_cmd('python main.py scenario --help')
        assert 'Usage' in output
        assert 'Commands' in output
        assert 'add' in output
        assert 'list' in output
        assert 'remove' in output

    @WorkingDirectory(ROOT)
    def test_invoke_scenario_add_help(self):
        output = invoke_cmd('python main.py scenario add --help')
        assert 'Usage' in output
        assert 'scenario' in output
        assert 'add' in output
        assert '--camera' in output
        assert '--scenario' in output
        assert '--help' in output

    @WorkingDirectory(ROOT)
    def test_invoke_scenario_remove_help(self):
        output = invoke_cmd('python main.py scenario remove --help')
        assert 'Usage' in output
        assert 'scenario' in output
        assert 'remove' in output
        assert '--scenario' in output
        assert '--camera' in output
        assert '--help' in output

    @WorkingDirectory(ROOT)
    def test_invoke_scenario_list_help(self):
        output = invoke_cmd('python main.py scenario list --help')
        assert 'Usage' in output
        assert 'scenario' in output
        assert '--camera' in output
        assert '--help' in output

    @WorkingDirectory(ROOT)
    def test_invoke_scenario_add_remove(self):
        # cleanup (prior test failures)
        output = invoke_cmd('python main.py scenario remove --name TEST-999')

        # add camera
        output = invoke_cmd('python main.py camera add --name TEST-999 --uri youtube.com --description "Test camera"')
        assert 'Success' in output

        # add scenario
        output = invoke_cmd(f'python main.py scenario add --camera TEST-999 --scenario smoke-and-fire-detection')
        assert 'Scenario' in output
        assert 'smoke-and-fire-detection' in output
        assert 'added for camera' in output

        # list scenario
        output = invoke_cmd('python main.py scenario list --camera TEST-999')
        assert "Listing configured scenarios for" in output
        assert 'TEST-999' in output
        assert "'name': 'smoke-and-fire-detection'" in output

        # remove scenario
        output = invoke_cmd('python main.py scenario remove --camera TEST-999 --scenario smoke-and-fire-detection')
        assert 'Success' in output

        # list scenario
        output = invoke_cmd('python main.py scenario list  --camera TEST-999')
        assert "Listing configured scenarios for" in output
        assert 'TEST-999' in output
        assert "'name': 'smoke-and-fire-detection'" not in output

        # remove camera
        output = invoke_cmd('python main.py scenario remove --name TEST-999')




if __name__ == '__main__':
    unittest.main()



import typer
from rich import print
from typing import Optional
from pathlib import Path

app = typer.Typer()

# For taking input as a file or a directory
def main(config: Optional[Path] = typer.Option(None)):
    if config is None:
        print("No config file")
        raise typer.Abort()
    if config.is_file():
        text = config.read_text()
        print(f"Config file contents: {text}")
    elif config.is_dir():
        print("Config is a directory, will use all its config files")
    elif not config.exists():
        print("The config doesn't exist")


# To enable auto-complete
def complete_name():
    return ["Camila", "Carlos", "Sebastian"]

@app.command()
def main(
    name: str = typer.Option(
        "World", help="The name to say hi to.", autocompletion=complete_name
    )
):
    print(f"Hello {name}")


# Progress bar
import time
from rich.progress import track
def main():
    total = 0
    for value in track(range(100), description="Processing..."):
        # Fake processing time
        time.sleep(0.01)
        total += 1
    print(f"Processed {total} things.")


if __name__ == "__main__":
    app()


import typer
from rich import print

web_app = typer.Typer()



# web app
@web_app.command('start')
def web_start():
    '''
    Start web server

    Use this function to start the web-service. Web service
    can be used for more intuitive configuration for the
    cameras and scenarios. Web-app is also the place to view
    event details, camera live-stream etc.
    '''

    print(f'Starting web server')

@web_app.command('stop')
def web_stop(web: str=None):
    '''
    Stop web server

    Use this function to stop already running web-service. There
    can be a single instance of the web-service supported currently.
    So there is no need for any arguments for this function.
    '''

    print(f'Stop web server')

@web_app.command('status')
def web_status():
    '''
    Web service status

    Use this function to get the status of the web-service. (if
    its running or not. This function also prints diagnostic
    information like last few log messages etc.)
    '''
    print(f'Web service status')

@web_app.callback()
def callback():
    '''
    Web functions

    A web-app is more intuitive way of configuring scenarios,
    cameras and pipelines. These routines allow the user
    to start their own internal development server that
    can be used for managing scenarios, cameras and pipelines.
   '''

if __name__ == '__main__':
    web_app()



import os
import platform
import sys
from pathlib import Path
import typer

FILE = Path(__file__).resolve()
ROOT = FILE.parents[1]  # edgectl root directory
if str(ROOT) not in sys.path:
    sys.path.append(str(ROOT))  # add ROOT to PATH
ROOT = Path(os.path.relpath(ROOT, Path.cwd()))  # relative

from util.general import print_args, check_requirements, LOGGER

app = typer.Typer()

@app.command()
def list_devices():

def run(
    list_devices=False,
    use_device='oos-training',
    list_modules=False,
    gpu_stats=False,
    mem_stats=False,
    scenario_health=False,
    list_all_scenarios=False,
    list_scenarios=False,
    start_scenario=False,
    stop_scenario=False,
    camera=None,
    list_all_cameras=False,
    add_camera=None,
    camera_uri=None,
    remove_camera=None,
    start_livestream=None,
    stop_livestream=None,
    simulate_events=False,
    scenario=None,
    event=None,
    event_data=None
):
    print(f'list_devices {list_devices}')
    print(f'use_device {use_device}')
    print(f'list_modules {list_modules}')
    print(f'gpu_stats {gpu_stats}')
    print(f'mem_stats {mem_stats}')
    print(f'scenario_health {scenario_health}')
    print(f'list_all_scenarios {list_all_scenarios}')
    print(f'list_scenarios {list_scenarios}')
    print(f'start_scenario {start_scenario}')
    print(f'stop_scenario {stop_scenario}')
    print(f'camera {camera}')
    print(f'list_all_cameras {list_all_cameras}')
    print(f'add_camera {add_camera}')
    print(f'camera_uri {camera_uri}')
    print(f'remove_camera {remove_camera}')
    print(f'start_livestream {start_livestream}')
    print(f'stop_livestream {stop_livestream}')
    print(f'simulate_events {simulate_events}')
    print(f'scenario {scenario}')
    print(f'event {event}')
    print(f'event_data {event_data}')

    if list_devices:
        list_all_devices()
    elif use_device is not None:
        fix_default_device(use_device)
    elif list_modules:
        required()
        list_all_modules()
    elif

def parse_opt():
    parser = argparse.ArgumentParser()

    # Device commands
    devices = parser.add_argument_group('Device')
    devices.add_argument('--list-devices', action='store_true', help='show available devices')
    devices.add_argument('--use-device', type=str, default=None, help='fix default device')
    devices.add_argument('--list-modules', action='store_true', help='show available modules on device')
    devices.add_argument('--gpu-stats', action='store_true', help='show gpu stats for the edgedevice')
    devices.add_argument('--mem-stats', action='store_true', help='show mem stats for the device')
    devices.add_argument('--scenario-health', action='store_true', help='show scenario health for the device')

    # List all scenarios
    list_scenarios = parser.add_argument_group('List scenarios')
    list_scenarios.add_argument('--list-all-scenarios', action='store_true', help='list all available scenarios')

    # Scenario commands
    scenarios = parser.add_argument_group('Start/stop scenarios for a camera')
    scenarios.add_argument('--list-scenarios', action='store_true', help='list scenarios for camera [--camera CAM]')
    scenarios.add_argument('--start-scenario', action='store_true', help='start scenarios for camera [--camera CAM]')
    scenarios.add_argument('--stop-scenario', action='store_true', help='stop scenarios for camera [--camera CAM]')
    scenarios.add_argument('--camera', type=str, help='specify camera name')

    # List all cameras
    list_cameras = parser.add_argument_group('List all cameras')
    list_cameras.add_argument('--list-all-cameras', action='store_true', help='list all available cameras')

    # Add a camera
    add_camera = parser.add_argument_group('Add camera')
    add_camera.add_argument('--add-camera', type=str, help='add camera  [--camera CAM  --camera-uri URI]')
    add_camera.add_argument('--camera-uri', type=str, help='Specify camera URI (rtsp, rtmp, hls, https)')

    # Remove camera
    remove_camera = parser.add_argument_group('Remove camera')
    remove_camera.add_argument('--remove-camera', type=str, help='remove camera  [--camera CAM]')

    # Start/stop livestream
    start_livestream = parser.add_argument_group('Start/stop livestream')
    start_livestream.add_argument('--start-livestream', type=str, help='start livestream [--camera CAM]')
    start_livestream.add_argument('--stop-livestream', type=str, help='stop livestream [--camera CAM]')

    # Simulate event
    simulate_events = parser.add_argument_group('Simulate events')
    simulate_events.add_argument('--simulate-events', action='store_true', help='simulate an event')
    simulate_events.add_argument('--scenario', type=str, help='specify scenario')
    simulate_events.add_argument('--event', type=str, help='event name')
    simulate_events.add_argument('--event-data', type=str, help='event data json in "double quotes"')

    opt = parser.parse_args()
    print_args(vars(opt))
    return opt

def main():
    opt = parse_opt()
    run(**vars(opt))

    # check_requirements()
    # run(**vars(opt))

if __name__ == "__main__":
    main()


import os
import sys
import typer
import time
import json
from uuid import uuid4
from rich import print
from rich.progress import track
from pathlib import Path

FILE = Path(__file__).resolve()
ROOT = FILE.parents[1]  # visionai/visionai directory
if str(ROOT) not in sys.path:
    sys.path.append(str(ROOT))  # add ROOT to PATH

from config import CONFIG_FILE, SCENARIOS_SCHEMA

scenario_app = typer.Typer()

# scenario app
@scenario_app.command('list')
def scenario_all():
    '''
    List all scenarios available

    List all scenarios available in the system. This includes scenarios
    that may or maynot be applied to any specific camera.
    '''
    # TODO get the scenario from API
    # res = requests.get('/scenarios')
    print('Listing all scenarios available:')
    with open(SCENARIOS_SCHEMA, 'r') as f:
        data = json.load(f)
    print(data['scenarios'])

@scenario_app.command('list')
def scenario_list(
    camera = typer.Option(None, help="Camera name", prompt=True)
):
    '''
    List scenarios configured for a camera

    This method only lists scenarios configured for a given camera, or
    if no camera name is provided - it would list all scenarios available
    in the system.
    '''
    # Camera is available in system
    camera_scenarios = None
    if os.path.exists(CONFIG_FILE):
        with open(CONFIG_FILE, 'r') as f:
            config_data = json.load(f)
        for cam in config_data['cameras']:
            if cam['name'] == camera:
                camera_scenarios = cam['scenarios']
                break

    # Camera is available in system
    if camera_scenarios is not None:
        print(f'Listing configured scenarios for: {camera}')
        print(camera_scenarios)

    else:
        print(f'Listing all available scenarios')
        print(scenario_all())



@scenario_app.command('add')
def scenario_add(
    scenario: str = typer.Option(..., help='scenario name', prompt=True),
    camera: str = typer.Option(..., help='camera name', prompt=True)
    ):
    '''
    Add a scenario to be run for a camera

    Add an individual scenario to be run for a camera. Specify the
    names for scenario and camera.
    '''

    print(f'Adding scenario : {scenario} for camera: {camera}')
    if os.path.exists(CONFIG_FILE):
        with open(CONFIG_FILE, 'r') as f:
            config_data = json.load(f)

    else:
        config_data = {
            'version': '0.1',
            'cameras': []
            }

    # find camera
    found_camera = False
    for cam in config_data['cameras']:
        if cam['name'] == camera:
            found_camera = True

            scen_already_present = False
            for scen in cam['scenarios']:
                if scen['name'] == scenario:
                    scen_already_present = True
                    break

            if scen_already_present is False:
                cam['scenarios'].append({
                    'name': scenario,
                    'events': 'all',
                    'schedule': 'all',
                    'focus': 'all'
                })

                with open(CONFIG_FILE, 'w') as f:
                    json.dump(config_data, f, indent=4)

                print(f'Scenario {scenario} successfully added for camera {camera}')

            else:
                print(f'Scenario {scenario} already present for camera {camera}')

            break

    if not found_camera:
        print(f'Error: camera {camera} not available')
        return


@scenario_app.command('remove')
def scenario_remove(
    scenario: str=typer.Option(..., help='scenario name', prompt=True),
    camera: str=typer.Option(..., help='camera', prompt=True)
    ):
    '''
    Remove a scenario from the system

    Specify a named scenario that needs to be removed from
    the system. Once removed, all the scenarios and pre-process
    routines associated with the scenario will be removed.
    '''

    print(f'Removing scenario : {scenario} from camera {camera}')
    if not os.path.exists(CONFIG_FILE):
        print('No scenarios available in the system. Exiting.')
        return

    with open(CONFIG_FILE, 'r') as f:
        config_data = json.load(f)

    # Check if name already present
    found = False
    for cam in config_data['cameras']:
        for scen in cam['scenarios']:
            if scen['name'] == scenario:
                found = True
                cam['scenarios'].remove(scen)
                break

    if found:
        # Write back to JSON if successfully removed.
        with open(CONFIG_FILE, 'w') as f:
            json.dump(config_data, f, indent=4)

        print(f'Successfully removed scenario: {scenario} from {camera}')
    else:
        print(f'Unable to remove scenario {scenario} from {camera}')


@scenario_app.command('preview')
def scenario_preview(
    name:str = typer.Option(..., help='scenario name to preview')
    ):
    '''
    Preview the scenario feed

    View the scenario feed, review FPS etc available for scenario.
    '''
    print(f"TODO: Implement scenario preview functionality.")

@scenario_app.callback()
def callback():
    '''
    Manage scenarios

    An organization can have multiple scenarios that are installed
    at different places. They may be from different vendors and/or
    maybe using different security surveillance software. Most
    scenarios however do support RTSP, RTMP or HLS streams as an
    output. Please refer to your scenario vendor documentation to
    find this out. This module will help you onboard those scenarios
    on visionai systems by using a simple named instance for each
    scenario.
    '''

if __name__ == '__main__':
    scenario_app()

    # scenario_remove('smoke-and-fire-detection', 'TEST-999')
